4.33. umbra.managers.layoutsManager — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.33. umbra.managers.layoutsManager

layoutsManager.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `LayoutsManager` and `Layout` classes.

Others:

## 4.33.1. Module Attributes

`umbra.managers.layoutsManager.` `LOGGER`

## 4.33.2. Classes

class `umbra.managers.layoutsManager.` `Layout`(**kwargs)

  Bases: `foundations.dataStructures.Structure`

  This class represents a storage object for `LayoutsManager` class layout.

  Parameters: | **kwargs – name, identity, shortcut. ( Key / Value pairs )

class `umbra.managers.layoutsManager.` `LayoutsManager`(parent=None)

  Bases: `PyQt4.QtCore.QObject`

  This class defines the Application layouts manager.

  `layoutRestored`

    This signal is emited by the `LayoutsManager` class when the current layout has been restored. ( pyqtSignal )

    Returns: | Current layout. ( String )

  `layoutStored`

    This signal is emited by the `LayoutsManager` class when the current layout has been stored. ( pyqtSignal )

    Returns: | Current layout. ( String )

  `container`

    This method is the property for self.__container attribute.

    Returns: | self.__container. ( QObject )

  `settings`

    This method is the property for self.__settings attribute.

    Returns: | self.__settings. ( Preferences )

  `layouts`

    This method is the property for self.__layouts attribute.

    Returns: | self.__layouts. ( Dictionary )

  `currentLayout`

    This method is the property for self.__currentLayout attribute.

    Returns: | self.__currentLayout. ( Tuple / List )

  `restoreGeometryOnLayoutChange`

    This method is the property for self.__restoreGeometryOnLayoutChange attribute.

    Returns: | self.__restoreGeometryOnLayoutChange. ( Boolean )

  `listLayouts`()

    This method returns the registered layouts.

    Returns: | Registered layouts. ( List )

  `isLayoutRegistered`(name)

    This method returns if the given layout name is registered.

    Parameters: | name – Layout name. ( String )
    Returns: | Is layout registered. ( Boolean )

  `registerLayout`(name, layout)

    This method registers given layout.

    Parameters: | name – Layout name. ( String ) layout – Layout object. ( Layout )
    Returns: | Method success. ( Boolean )

  `unregisterLayout`(name)

    This method unregisters given layout.

    Parameters: | name – Layout name. ( String ) layout – Layout object. ( Layout )
    Returns: | Method success. ( Boolean )

  `restoreLayout`(name, *args)

    This method restores given layout.

    Parameters: | name – Layout name. ( String ) *args – Arguments. ( * )
    Returns: | Method success. ( Boolean )

  `storeLayout`(name, *args)

    This method stores given layout.

    Parameters: | name – Layout name. ( String ) *args – Arguments. ( * )
    Returns: | Method success. ( Boolean )

  `restoreStartupLayout`()

    This method restores the startup layout.

    Returns: | Method success. ( Boolean )

  `storeStartupLayout`()

    This method stores the startup layout.

    Returns: | Method success. ( Boolean )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »